Returns the objective value given a design vector as well an an objective function. This is code duplication since this is implemented within Java. This is only to be run if...
compute_objective_val_plus_one_min_one_enc(
X,
indic_T,
objective = "abs_sum_diff",
inv_cov_X = NULL
)The n x p design matrix
The n-length binary allocation vector
The objective function to use. Default is abs_sum_diff.
Optional: the inverse sample variance covariance matrix. Use this argument if you will be doing many calculations since passing this in will cache this data.
A vector of computed objective values.